@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright 2014 - StackStorm, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,17 +12,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from django.template.defaultfilters import title
+from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon import tables
 
 from mistraldashboard import api
-import mistraldashboard.default.SmartCell as SmartCell
+from mistraldashboard.default import smart_cell
 from mistraldashboard.default.utils import humantime
 from mistraldashboard.default.utils import label
 
-SmartCell.init()
+smart_cell.init()
 
 
 class UpdateRow(tables.Row):
@@ -33,21 +33,31 @@ class UpdateRow(tables.Row):
     def get_data(self, request, id):
         try:
             instance = api.task_get(request, id)
-        except Exception as e:
-            msg = _("Unable to get task by ID %(id)s: %(e)s.") % {
-                'id': id, 'e': str(e)
-            }
+        except Exception:
+            msg = _('Unable to get task by ID "%s".') % id
             exceptions.handle(request, msg)
-
         return instance
 
 
+class TypeColumn(tables.Column):
+    def get_link_url(self, datum):
+        obj_id = datum.id
+        url = ""
+        action_execution_url = "horizon:mistral:action_executions:task"
+        workflow_execution_url = "horizon:mistral:executions:tasks"
+        if datum.type == "ACTION":
+            url = action_execution_url
+        elif datum.type == "WORKFLOW":
+            url = workflow_execution_url
+
+        return reverse(url, args=[obj_id])
+
+
 class TaskTable(tables.DataTable):
 
     def getHoverHelp(data):
         if hasattr(data, 'state_info') and data.state_info:
-
-                return {'title': data.state_info}
+            return {'title': data.state_info}
 
     STATE_STATUS_CHOICES = (
         ("success", True),
@@ -70,6 +80,12 @@ class TaskTable(tables.DataTable):
         verbose_name=_("Workflow Execution ID"),
         link="horizon:mistral:executions:detail_task_id"
     )
+    type = TypeColumn(
+        "type",
+        verbose_name=_("Type"),
+        filters=[title],
+        link=True
+    )
     result = tables.Column(
         "",
         verbose_name=_("Result"),
